Beetry Plugin
This crate is an internal Beetry implementation crate and is not considered
part of the public API. For public APIs, use the beetry crate.
This crate provides the plugin related functionality.
Re-exports
pub use crate::node::ParamsDeserializer;pub use crate::node::ProvideParamSpec;pub use inventory;
Modules
Macros
- action
- Creates an action plugin from Beetry’s leaf-node DSL.
- channel
- Creates a channel plugin for a message type.
- condition
- Creates a condition plugin from Beetry’s leaf-node DSL.
- control
- Creates a control plugin for nodes that manage multiple children.
- decorator
- Creates a decorator plugin for nodes that wrap a single child.
- submit