macro_rules! condition {
($plugin_name:ident : $name:expr; $($tokens:tt)*) => { ... };
}Expand description
Creates a condition plugin from Beetry’s leaf-node DSL.
Use when the node evaluates to success or failure without producing child nodes.
The DSL is the same as action!: receivers, senders, params, and
create work the same way, but the constructed behavior must implement
ConditionBehavior instead of ActionBehavior.